![Upload Python Package](https://github.com/sendpulse/sendpulse-rest-api-python/workflows/Upload%20Python%20Package/badge.svg?event=release)

# sendpulse-rest-api

A simple SendPulse REST client library and example for Python.

## Install using pipy

```sh
# version 0.0.3
pip install pysendpulse
```

## Examples

See a list of examples [here](https://github.com/sendpulse/sendpulse-rest-api-python/blob/master/pysendpulse/examples/sendpulse-rest-api-example.py)
